<?php

# http://telechargements.pluxml.org/docs/PluXml_-_Plugins_Guide_du_developpeur.pdf

if (!defined('PLX_ROOT')) { exit; }

define('DEFAULT_PASSWORD', 'PluXml');

class users_csv extends plxPlugin {

	public function __construct($default_lang) {

		# Appel du constructeur de la classe plxPlugin (obligatoire)
		parent::__construct($default_lang);

		$this->setConfigProfil(PROFIL_ADMIN);

		# Accès au menu admin réservé au profil administrateur
		$this->setAdminProfil(PROFIL_ADMIN);

		# Personnalisation du menu admin
		$this->setAdminMenu($this->getLang('MENU_NAME'), 0, $this->getLang('MENU_TITLE'));

		# Ajouts des hooks
		$this->addHook('AdminUsersFoot', 'AdminUsersFoot'); # formulaire saisie multi_users
		$this->addHook('plxAdminEditUsersUpdate', 'plxAdminEditUsersUpdate');
		$this->signature = filemtime(__FILE__);
	}

	public function printForm($admin=false) {

		$phpScripts = array_filter(
			array_map(
				function ($item) {
					return basename($item);
				},
				glob(__DIR__.'/*.php')
			),
			function($item) {
				return $item != __CLASS__.'.php';
			}
		);
		$action =  (! $admin) ?  ' action="'.PLX_PLUGINS.__CLASS__.'/'.array_values($phpScripts)[0].'"' : '';
?>
	<div id="div_users-csv">
		<h3 title="<?php $this->lang('MENU_TITLE'); ?>"><?php $this->lang('MENU_NAME'); ?> <span>( with <?php echo __CLASS__; ?> plugin )</span></h3>
		<form id="form_users-csv" method="POST" enctype="multipart/form-data"<?php echo $action; ?>>
			<p>
				<label for="id_separator"><?php $this->lang('SEPARATOR')?></label>
				<select id="id_separator" name="separator">
					<option value=",">,</option>
					<option value=";" selected>;</option>
					<option value="tab"><?php $this->lang('TABULATION'); ?></option>
					<option value=" "><?php $this->lang('SPACE'); ?></option>
				</select>
				<label for="id_enclosure"><?php $this->lang('ENCLOSURE')?></label>
				<select id="id_enclosure" name="enclosure">
					<option value=""><?php $this->lang('EMPTY'); ?></option>
					<option value="&quot;" selected>&quot;</option>
					<option value="'">'</option>
				</select>
			</p>
			<p>
				<input type="hidden" name="users-csv" value="<?php echo $this->signature; ?>">
				<input id="users-csv-file" name="users-csv-file" type="file" accept=".csv" required />
				<input type="submit">
				<input type="button" id="users-csv-preview-btn" value="<?php $this->lang('PREVIEW'); ?>" disabled>
				<input type="submit" id="users-csv-export" name="users-csv-export" value="Exporter">
			</p>
		</form>
		<p><?php echo str_replace('##PASSWORD##', DEFAULT_PASSWORD, $this->getLang('PASSWORD')); ?></p>
		<div id="users-csv-preview">
			<table></table>
			<p><input type="button" value="<?php $this->lang('CLOSE'); ?>" /></p>
		</div>
<?php
	if(! empty($_SESSION[__CLASS__]['warning'])) {
		echo '<p>'.$_SESSION[__CLASS__]['warning']."</p>\n";
		unset($_SESSION[__CLASS__]['warning']);
	}

	$minify = (is_readable(__DIR__.'/'.__CLASS__.'.min.js')) ? '.min' : '';
	$scriptname = PLX_PLUGINS.__CLASS__.'/'.__CLASS__.$minify.'.js';
?>
	<script type="text/javascript" src="<?php echo $scriptname; ?>"></script>
<?php
	}

	public function AdminUsersFoot() {
		$this->printForm();
	}

	public function plxAdminEditUsersUpdate() {

		echo <<< 'EOT'
<?php
foreach(explode(' ', 'lang email infos') as $csv_fld) {
	if(! empty($content[$user_id.'_'.$csv_fld])) {
		$this->aUsers[$user_id][$csv_fld] = $content[$user_id.'_'.$csv_fld];
	}
}
?>
EOT;

	}

}
?>